# Over the Top
## What is "Over the Top"?
<p>Over the Top is a 2d WW1 styled strategy game that is currently still in development, however with the current version, it is possible to try out the basic outline of the game, but dont expect anything extraordinary</p>

## Y though?
<p>I made this game because I like playing strategy games, and I know Python and I have experience with the Pygame library.</p>

## How though?
<p>The game is currently very early in the development stage, so for now you can play only a few levels to try it out.</p>
<p>The game is very simple, you just buy different types of units, and send them acros the fields to take enemy trenches</p>
<p>**Dont worry if you dont like overly complicated games** the enemy is currently suffering from heavy lobotomy so its easy to play :) </p>

## Current game features
- [x] First few testing levels
- [x] Some simple computer enemy
- [x] Real time units spawning
- [x] Units selection control menu
- [] Different nations with different units #coming soon
- [] Special actions like artilery or gas attack #coming soon
- [] Resizability of the entire game #coming soon
- [] Better images, and UI #coming soon

## Controls
<p>A, D for camera movement</p>
<p>Left arrow and right arrow for faster camera movement</p>
<p>You can buy units by simply clicking the bottom menu</p>
<p>You can also select units by simply clicking them to select and then right clicking to open a command menu, and give them specific commands, like attack and fallback</p>
<p>Other parts of the game are pretty intuitive, like selecting the level or the test mode</p>

### The trench menu explanation

<p>The trench menu is very simple, you can click the left arrow to tell the units to fall back, the right arrow to send them into attack, the arrow aiming to the top is the menu opening arrow, once clicked it will show all types of units in the trench and you can specificaly send one type of units into attack. The most interesting is the red light/green light button, if it is set to green, then all the units regardless of the type will be send through to the next trench.</p>

## Screenshots

## Download instructions